@@ -20,6 +20,8 @@ sub open {
     $self->is_open(1);
 }
 
+=encoding utf8
+
 =head1 NAME 
 
 IO::All::String - String IO Support for IO::All
@@ -32,12 +34,14 @@ See L<IO::All>.
 
 =head1 AUTHOR
 
-Brian Ingerson <INGY@cpan.org>
+Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
 Copyright (c) 2004. Brian Ingerson. All rights reserved.
 
+Copyright (c) 2006, 2008. Ingy döt Net. All rights reserved.
+
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
