@@ -15,6 +15,8 @@ sub temp {
     return $self;
 }
 
+=encoding utf8
+
 =head1 NAME 
 
 IO::All::Temp - Temporary File Support for IO::All
@@ -27,11 +29,13 @@ See L<IO::All>.
 
 =head1 AUTHOR
 
-Brian Ingerson <INGY@cpan.org>
+Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004. Brian Ingerson. All rights reserved.
+Copyright (c) 2004. Brian Ingerson.
+
+Copyright (c) 2006, 2008. Ingy döt Net.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
